#
# spec file for package ghc-postgresql-libpq
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name postgresql-libpq
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.10.1.0
Release:        2.3
Summary:        Low-level binding to libpq
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/1.cabal#/%{pkg_name}.cabal
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-Cabal-prof
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-unix-devel
BuildRequires:  ghc-unix-prof
BuildRequires:  postgresql-server-devel
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-hunit-devel
BuildRequires:  ghc-tasty-hunit-prof
BuildRequires:  ghc-tasty-prof
%endif

%description
This is a binding to libpq: the C application programmer's interface to
PostgreSQL. libpq is a set of library functions that allow client programs to
pass queries to the PostgreSQL backend server and to receive the results of
these queries.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires:       postgresql-server-devel
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development
files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}
cp -p %{SOURCE1} %{pkg_name}.cabal

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Tue Jul  9 2024 Peter Simons <psimons@suse.com>
- Update postgresql-libpq to version 0.10.1.0 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Apr 18 2024 Peter Simons <psimons@suse.com>
- Update postgresql-libpq to version 0.10.1.0.
  0.10.1.0
  - -------
  - Fix issue with empty binary values (https://github.com/haskellari/postgresql-libpq/issues/54)
* Sun Nov 19 2023 Peter Simons <psimons@suse.com>
- Update postgresql-libpq to version 0.10.0.0 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Sun Jul 30 2023 Peter Simons <psimons@suse.com>
- Update postgresql-libpq to version 0.10.0.0.
  0.10.0.0
  - -------
  There are technicallly two breaking changes in this release,
  but they shouldn't affect anyone not doing anything weird.
  - Binary parameters are passed without copying.
  - FFI functions are imported without `unsafe`. Most uses were incorrect.
    We make all calls "safe", as checking whether libpq functions do IO
    or may call a notifier (potentially calling back into Haskell),
    is virtually impossible for all versions of libpq.
    (The above properties are not specified in the documentation).
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Wed Mar 29 2023 Peter Simons <psimons@suse.com>
- Update postgresql-libpq to version 0.9.5.0 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Jan  5 2023 Peter Simons <psimons@suse.com>
- Update postgresql-libpq to version 0.9.5.0.
  0.9.5.0
  - ------
  - Drop support for GHCs prior 8.6
  - Require libpq >=10.22 (when using pkgconfig).
  - Use CApiFFI for some parts of the API
    (we cannot use for all due https://gitlab.haskell.org/ghc/ghc/-/issues/22043)
* Sun Oct  9 2022 Peter Simons <psimons@suse.com>
- Update postgresql-libpq to version 0.9.4.3 revision 3.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon Nov 15 2021 psimons@suse.com
- Update postgresql-libpq to version 0.9.4.3 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Sun Feb 21 2021 psimons@suse.com
- Update postgresql-libpq to version 0.9.4.3 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Nov  3 2020 psimons@suse.com
- Update postgresql-libpq to version 0.9.4.3.
  0.9.4.3
  - ------
  - Support `bytestring-0.11`
  - Allow `Win32-2.10.0.0`
  - Make `PQconsumeInput` FFI call `safe`
* Mon Aug 31 2020 psimons@suse.com
- Update postgresql-libpq to version 0.9.4.2 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Fri May 29 2020 psimons@suse.com
- Add postgresql-libpq at version 0.9.4.2.
